==> fam_2.6.6.1.orig.tar.gz: fam-2.6.6.1/acconfig.h <==
/*
**  acconfig.h
**
**  This file contains macro definitions & comments which are used by
**  "autoheader" and "configure" to generate config.h.
*/

/*  Define if the C++ compiler supports a built-in bool type.  */
#undef HAVE_BOOL

/*  Define if the C++ compiler supports namespaces.  */
#undef HAVE_NAMESPACE

/*  Define if we have nfs_clnt.h */
#undef HAVE_SYS_FS_NFS_CLNT_H

/*  Define if the system has imon and IMONIOC_ ioctl flags.  */
#undef HAVE_IMON

/*  Define if the system has the dnotify fcntl and it's gonna be used.  */
#undef USE_DNOTIFY

/*  Define if the system has the struct revokdi and the IMONIOC_REVOKDI
**  ioctl flag.  (IRIX 5.3 doesn't.)
*/
#undef HAVE_IMON_REVOKDI

/*  Define if we have statvfs.  Otherwise, statfs will be used.  */
#undef HAVE_STATVFS

/*  Define if we have stat.st_fstype (a char array).  */
#undef HAVE_STAT_ST_FSTYPE_STRING

/*  Define if we have stat.st_ctim.tv_nsec (nanoseconds).  */
#undef HAVE_STAT_ST_CTIM_TV_NSEC

/*  Define if we have syssgi.  */
#undef HAVE_SYSSGI

/*  Define if we have sgi nohang.  */
#undef HAVE_SGI_NOHANG

/*  Define if we have _daemonize.  */
#undef HAVE_DAEMONIZE

/*  Define if we have prmap_sgi_t  */
#undef HAVE_PRMAP_SGI_T

/*  Define if we have FSID_NFS, FSID_NFS2, FSID_NFS3, and FSID_CACHEFS.
**  Otherwise, we'll use MNTTYPE_NFS.  */
#undef HAVE_FSID_NFS2

/* Define if we have MNTTYPE_NFS2 */
#define HAVE_MNTTYPE_NFS2 0

/* Define if we have MNTTYPE_NFS3 */
#define HAVE_MNTTYPE_NFS3 0

/* Define if we have MNTTYPE_CACHEFS */
#define HAVE_MNTTYPE_CACHEFS 0

/*  Define if we have a prototype for bindresvport().  */
#undef HAVE_BINDRESVPORT_PROTO

/*  Define if mountlist is a struct in rpcsvc/mount.h containing the member
**  ml_host.
*/
#undef HAVE_MOUNTLIST_STRUCT

/*  Define if mountlist is a pointer-to-struct in rpcsvc/mount.h containing
**  the member ml_hostname.
*/
#undef HAVE_MOUNTLIST_PTR

/*  Define if we have getgrmember.
*/
#undef HAVE_GETGRMEMBER

/*  Define if we have sys/sat.h, satvwrite(), and _SC_AUDIT.  */
#undef HAVE_AUDIT

/*  Define if we have sys/mac.h and t6net.h, tsix_get_mac and mac_get_file(),
**  and _SC_MAC and _SC_IP_SECOPTS.
*/
#undef HAVE_MAC

/*  Define if we have snprintf in stdio.h.  */
/* #undef HAVE_SNPRINTF */

/*  Define if you have /etc/xtab in the IRIX format.
*/
#undef HAVE_IRIX_XTAB_VERIFICATION

/*  Define to be statvfs_t.f_fsid's type (ulong_t or __fsid_t)
*/
#undef CONFIG_FSID_T

/*  Define to be the type of the third argument to accept(2) (socklen_t or
**  int)
*/
#undef CONFIG_SOCKLEN_T

/*  why do I have to have these?  PACKAGE and VERSION are defined by
    AM_INIT_AUTOMAKE, and the examples don't say anything about having
    to mess with these things elsewhere. */
#undef PACKAGE
#undef VERSION

==> fam-2.6.9.tar.gz: fam-2.6.9/acconfig.h <==
/*
**  acconfig.h
**
**  This file contains macro definitions & comments which are used by
**  "autoheader" and "configure" to generate config.h.
*/

/*  Define if the C++ compiler supports a built-in bool type.  */
#undef HAVE_BOOL

/*  Define if the C++ compiler supports namespaces.  */
#undef HAVE_NAMESPACE

/*  Define if we have nfs_clnt.h */
#undef HAVE_SYS_FS_NFS_CLNT_H

/*  Define if the system has imon and IMONIOC_ ioctl flags.  */
#undef HAVE_IMON

/*  Define if the system has the struct revokdi and the IMONIOC_REVOKDI
**  ioctl flag.  (IRIX 5.3 doesn't.)
*/
#undef HAVE_IMON_REVOKDI

/*  Define if we have statvfs.  Otherwise, statfs will be used.  */
#undef HAVE_STATVFS

/*  Define if we have stat.st_fstype (a char array).  */
#undef HAVE_STAT_ST_FSTYPE_STRING

/*  Define if we have stat.st_ctim.tv_nsec (nanoseconds).  */
#undef HAVE_STAT_ST_CTIM_TV_NSEC

/*  Define if we have syssgi.  */
#undef HAVE_SYSSGI

/*  Define if we have sgi nohang.  */
#undef HAVE_SGI_NOHANG

/*  Define if we have _daemonize (IRIX).  */
#undef HAVE_DAEMONIZE

/*  Define if we have daemon (Linux/BSD).  */
#undef HAVE_DAEMON

/*  Define if we have prmap_sgi_t  */
#undef HAVE_PRMAP_SGI_T

/*  Define if we have FSID_NFS, FSID_NFS2, FSID_NFS3, and FSID_CACHEFS.
**  Otherwise, we'll use MNTTYPE_NFS.  */
#undef HAVE_FSID_NFS2

/* Define if we have MNTTYPE_NFS2 */
#define HAVE_MNTTYPE_NFS2 0

/* Define if we have MNTTYPE_NFS3 */
#define HAVE_MNTTYPE_NFS3 0

/* Define if we have MNTTYPE_CACHEFS */
#define HAVE_MNTTYPE_CACHEFS 0

/*  Define if we have a prototype for bindresvport().  */
#undef HAVE_BINDRESVPORT_PROTO

/*  Define if mountlist is a struct in rpcsvc/mount.h containing the member
**  ml_host.
*/
#undef HAVE_MOUNTLIST_STRUCT

/*  Define if mountlist is a pointer-to-struct in rpcsvc/mount.h containing
**  the member ml_hostname.
*/
#undef HAVE_MOUNTLIST_PTR

/*  Define if we have getgrmember.
*/
#undef HAVE_GETGRMEMBER

/*  Define if we have sys/sat.h, satvwrite(), and _SC_AUDIT.  */
#undef HAVE_AUDIT

/*  Define if we have sys/mac.h and t6net.h, tsix_get_mac and mac_get_file(),
**  and _SC_MAC and _SC_IP_SECOPTS.
*/
#undef HAVE_MAC

/*  Define if we have snprintf in stdio.h.  */
/* #undef HAVE_SNPRINTF */

/*  Define if you have /etc/xtab in the IRIX format.
*/
#undef HAVE_IRIX_XTAB_VERIFICATION

/*  Define to be statvfs_t.f_fsid's type (ulong_t or __fsid_t)
*/
#undef CONFIG_FSID_T

/*  Define to be the type of the third argument to accept(2) (socklen_t or
**  int)
*/
#undef CONFIG_SOCKLEN_T

/*  why do I have to have these?  PACKAGE and VERSION are defined by
    AM_INIT_AUTOMAKE, and the examples don't say anything about having
    to mess with these things elsewhere. */
#undef PACKAGE
#undef VERSION
